@@ -1,26 +1,29 @@
-__all__ = ["start", "stop"]
+__all__ = []
 
 from .. import error, helper
 from ..helper.time_fractions import TimeFractions
-from ..model.timer import TimerObject
+from ..model.timer_base import TimerBase
 
-def start(timer: TimerObject, thread: str | None, start_time: int, decimals: int | None) -> None:
+
+def start(timer: TimerBase, thread: str | None, start_time: int, decimals: int | None) -> None:
     try:
         thread = helper.thread.normalise_to_string_and_uppercase(thread)
         decimals = helper.decimals.mediate(timer, decimals)
         thread_item, _ = helper.thread.list.try_get_thread_item_and_index(timer, thread)
-        if thread_item is None: # If no match in existing threads, create new entry in the thread list.
+        if thread_item is None:  # If no match in existing threads, create new entry in the thread list.
             helper.thread.list.add(timer, thread, start_time, decimals)
         else:
             error.start_controller(thread)
     except Exception:
-        error.message_for_action("in the Timer's start thread controller", thread = thread)
+        error.message_for_action("in the Timer's start thread controller", thread)
 
-def stop(timer: TimerObject, thread: str | None, stop_time: int) -> None:
+
+def stop(timer: TimerBase, thread: str | None, stop_time: int) -> None:
     try:
         thread = helper.thread.normalise_to_string_and_uppercase(thread)
         thread_item, entry_index = helper.thread.list.try_get_thread_item_and_index(timer, thread)
-        if thread_item is not None and entry_index is not None: # If there's a match in existing threads, return values to the stop function and remove the entry.
+        # If there's a match in existing threads, return values to the stop function and remove the entry.
+        if thread_item is not None and entry_index is not None:
             helper.thread.list.remove(timer, entry_index)
             elapsed_time = stop_time - thread_item.start_time
             time_fractions = TimeFractions(elapsed_time)
@@ -28,4 +31,4 @@ def stop(timer: TimerObject, thread: str | None, stop_time: int) -> None:
         else:
             error.stop_controller(timer, thread)
     except Exception:
-        error.message_for_action("in the Timer's stop thread controller", thread = thread)
+        error.message_for_action("in the Timer's stop thread controller", thread)
