@@ -1,14 +1,19 @@
 from colorist import Color
-from ..constant.decimals import DEFAULT, MAXIMUM, MINIMUM
-from .. import error
-from ..model.timer import TimerObject
 
-def mediate(timer: TimerObject, decimals: int | None) -> int: # If the start function doesn't have decimals defined, then use the decimals value defined when the Timer() was initiated.
+from .. import error
+from ..constant.decimals import DEFAULT, MAXIMUM, MINIMUM
+from ..model.timer_base import TimerBase
+
+
+def mediate(timer: TimerBase, decimals: int | None) -> int:
+    """If the start function doesn't have decimals defined, then use the decimals value defined when the Timer() was initiated."""
+
     return timer.decimals if decimals is None else validate_and_normalise(decimals)
 
+
 def validate_and_normalise(decimals: int | None) -> int:
     try:
-        if isinstance(decimals, (str, list, dict, tuple)) is True or decimals is None:
+        if isinstance(decimals, (str, list, dict, tuple)) or decimals is None:
             print(f"{Color.YELLOW}Timer: Decimals set to default {DEFAULT} due to invalid input.{Color.OFF}")
             return DEFAULT
         elif decimals > MAXIMUM:
